.. This file is a part of the AnyBlok project
..
..    Copyright (C) 2014 Jean-Sebastien SUZANNE <jssuzanne@anybox.fr>
..
.. This Source Code Form is subject to the terms of the Mozilla Public License,
.. v. 2.0. If a copy of the MPL was not distributed with this file,You can
.. obtain one at http://mozilla.org/MPL/2.0/.

.. contents::

Bloks
=====

Blok anyblok-core
-----------------

.. automodule:: anyblok.bloks.anyblok_core
.. autoclass:: AnyBlokCore
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok/bloks/anyblok_core/README.rst
.. include:: ../anyblok/bloks/anyblok_core/CODE.rst

Blok IO
-------

.. automodule:: anyblok.bloks.io
.. autoclass:: AnyBlokIO
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok/bloks/io/README.rst
.. include:: ../anyblok/bloks/io/CODE.rst

Blok IO CSV
-----------

.. automodule:: anyblok.bloks.io_csv
.. autoclass:: AnyBlokIOCSV
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok/bloks/io_csv/README.rst
.. include:: ../anyblok/bloks/io_csv/CODE.rst

Blok IO XML
-----------

.. automodule:: anyblok.bloks.io_xml
.. autoclass:: AnyBlokIOXML
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok/bloks/io_xml/README.rst
.. include:: ../anyblok/bloks/io_xml/CODE.rst

Blok Model Auth
---------------

.. automodule:: anyblok.bloks.model_authz
.. autoclass:: ModelBasedAuthorizationBlok
    :members:
    :undoc-members:
    :show-inheritance:
    :noindex:

.. include:: ../anyblok/bloks/model_authz/README.rst
.. include:: ../anyblok/bloks/model_authz/CODE.rst
